MCD inheritance
LACUS ( magna, vestibulum, tempor, fugit )

- Le champ magna constitue la clé primaire de la table. Il était clé primaire de l'entité-mère TRISTIS (supprimée).
- Le champ vestibulum est un simple attribut. Il était simple attribut de l'entité-mère TRISTIS (supprimée).
- Les champs tempor et fugit étaient déjà de simples attributs de l'entité LACUS.

NEC ( magna, vestibulum, pulvinar, audis, #magna via_mollis!, #magna via_vitae! )

- Le champ magna constitue la clé primaire de la table. Il était clé primaire de l'entité-mère TRISTIS (supprimée).
- Le champ vestibulum est un simple attribut. Il était simple attribut de l'entité-mère TRISTIS (supprimée).
- Les champs pulvinar et audis étaient déjà de simples attributs de l'entité NEC.
- Le champ à saisie obligatoire magna via_mollis est une clé étrangère. Il a migré par l'association de dépendance fonctionnelle MOLLIS à partir de l'entité LACUS en perdant son caractère identifiant.
- Le champ à saisie obligatoire magna via_vitae est une clé étrangère. Il a migré par l'association de dépendance fonctionnelle VITAE à partir de l'entité SODALES en perdant son caractère identifiant.

SODALES ( magna, vestibulum, convallis, ipsum )

- Le champ magna constitue la clé primaire de la table. Il était clé primaire de l'entité-mère TRISTIS (supprimée).
- Le champ vestibulum est un simple attribut. Il était simple attribut de l'entité-mère TRISTIS (supprimée).
- Les champs convallis et ipsum étaient déjà de simples attributs de l'entité SODALES.

ULTRICES ( #magna sodales, #magna lacus )

- Le champ magna sodales fait partie de la clé primaire de la table. C'est une clé étrangère qui a migré directement à partir de l'entité SODALES.
- Le champ magna lacus fait partie de la clé primaire de la table. C'est une clé étrangère qui a migré directement à partir de l'entité LACUS.